OC.L10N.register(
    "settings",
    {
    "Private" : "Privadu",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visìbile isceti a is persones agatadas cun integratzione de su nùmeru de telèfonu tràmite Talk in mobile",
    "Local" : "Locale",
    "Only visible to people on this instance and guests" : "Visìbile isceti a is persones invitadas e a is de custa istàntzia",
    "Federated" : "Federadu",
    "Only synchronize to trusted servers" : "Sincroniza cun serbidores seguros ebbia",
    "Published" : "Publicadu",
    "Synchronize to trusted servers and the global and public address book" : "Sincroniza cun serbidores seguros e sa rubrica globale e pùblica",
    "Verify" : "Avèrgua",
    "Verifying …" : "Averguende ...",
    "Unable to change password" : "Impossìbile a cambiare sa crae",
    "Very weak password" : "Crae dèbile a beru",
    "Weak password" : "Crae dèbile",
    "So-so password" : "Crae aici aici",
    "Good password" : "Crae bona",
    "Strong password" : "Crae bona a beru",
    "Groups" : "Grupos",
    "Group list is empty" : "S'elencu de is grupos est bòida",
    "Unable to retrieve the group list" : "Non faghet a recuperare s'elencu de is grupos",
    "{actor} added you to group {group}" : "{actor} t'at agiuntu a su grupu {group}",
    "You added {user} to group {group}" : "As agiuntu a {user} a su grupu {group}",
    "{actor} added {user} to group {group}" : "{actor} at agiuntu a {user} a su grupu {group}",
    "An administrator added you to group {group}" : "Un'utente de s'amministratzione t'at agiuntu a su grupu {group}",
    "An administrator added {user} to group {group}" : "Un'utente de s'amministratzione at agiuntu a {user} a su grupu {group}",
    "{actor} removed you from group {group}" : "{actor} ti nch'at bogadu dae su grupu {group}",
    "You removed {user} from group {group}" : "Nch'as bogadu a {user} dae su grupu {group}",
    "{actor} removed {user} from group {group}" : "{actor} nch'at bogadu a {user} dae su grupu {group}",
    "An administrator removed you from group {group}" : "Un'utente de s'amministratzione ti nch'at bogadu dae su grupu {group}",
    "An administrator removed {user} from group {group}" : "Un'utente de s'amministratzione nch'at bogadu a {user} dae su grupu {group}",
    "Your <strong>group memberships</strong> were modified" : "Is <strong>partetzipadas a is grupos</strong> tuas sunt istadas modificadas",
    "{actor} changed your password" : "{actor} at cambiadu sa crae tua",
    "You changed your password" : "As cambiadu sa crae tua",
    "Your password was reset by an administrator" : "S'amministratzione at torradu a impostare sa crae tua",
    "Your password was reset" : "Sa crae tua s'est torrada a impostare",
    "{actor} changed your email address" : "{actor} at cambiadu s'indiritzu tuo de posta eletrònica",
    "You changed your email address" : "As cambiadu s'indiritzu tuo de posta eletrònica",
    "Your email address was changed by an administrator" : "S'amministratzione at cambiadu s'indiritzu tuo de posta eletrònica",
    "You deleted app password \"{token}\"" : "As cantzelladu sa crae de s'aplicatzione \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "As cambiadu su nùmene de sa crae dae \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "As permìtidu s'atzessu a filesystem a sa crae de s'aplicatzione \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "As iscontzadu s'atzessu a filesystem dae sa crae de s'aplicatzione \"{token}\"",
    "Security" : "Seguresa",
    "You successfully logged in using two-factor authentication (%1$s)" : "As fatu s'atzessu cun s'autenticatzione a duos fatores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Unu tentativu de atzessu cun autenticatzione a duos fatores est faddidu (%1$s)",
    "Remote wipe was started on %1$s" : "Cantzelladura remota aviada in %1$s",
    "Remote wipe has finished on %1$s" : "Cantzelladura remota acabbada in %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "S'at modificadu sa <strong>crae</strong> o s'<strong>indiritzu de posta</strong> tuo",
    "Settings" : "Cunfiguratziones",
    "Wrong password" : "Crae isballiada",
    "Saved" : "Sarvadu",
    "Authentication error" : "Errore de autenticatzione",
    "Wrong admin recovery password. Please check the password and try again." : "Crae amministrativa de riprìstinu isballiada. Controlla·dda e torra a proare.",
    "Administrator documentation" : "Documentatzione amministratzione",
    "User documentation" : "Documentatzione utente",
    "Invalid SMTP password." : "Crae SMTP non bàlida.",
    "Email setting test" : "Proa de cunfiguratzione de posta eletrònica",
    "Well done, %s!" : "Bene fatu, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si as retzidu custu messàgiu de posta, sa cunfiguratzione de sa posta eletrònica est andada bene.",
    "Email could not be sent. Check your mail server log" : "Impossìbile a imbiare su messàgiu. Controlla s'informe de su serbidore tuo de posta",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ddoe at àpidu unu problema in s'imbiu de su messàgiu. Controlla sa cunfiguratzione. (Errore: %s)",
    "Invalid mail address" : "Indiritzu de posta non bàlidu",
    "Settings saved" : "Cunfiguratziones sarvadas",
    "Unable to change full name" : "Impossìbile a cambiare su nùmene",
    "Unable to change email address" : "Non faghet a cambiare s'indiritzu de posta eletrònica",
    "Unable to set invalid phone number" : "Non faghet a impostare nùmeru de telèfonu non bàlidu",
    "Unable to set invalid website" : "Impossìbile a impostare unu situ non bàlidu",
    "Some account data was invalid" : "Unos datos de su contu non finat bàlidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pro verificare su contu de Twitter tuo, pùblica in Tweeter su tweet in fatu (assegura·ti de ddu publicare in una lìnia ebbia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pro verificare su situ tuo, sarva su cuntenutu in fatu in sa raighina de su situ in '.well-known/CloudIdVerificationCode.txt' (assegura·ti chi siat in una lìnia ebbia):",
    "%1$s changed your password on %2$s." : "%1$s at cambiadu sa crae tua in %2$s.",
    "Your password on %s was changed." : "Sa crae tua de %s est istada cambiada.",
    "Your password on %s was reset by an administrator." : "S'amministratzione at torradu a impostare sa crae tua de %s. ",
    "Your password on %s was reset." : "Sa crae tua de %s s'est torrada a impostare.",
    "Password for %1$s changed on %2$s" : "Sa crae pro %1$s est cambiada in %2$s",
    "Password changed for %s" : "Crae cambiada pro %s",
    "If you did not request this, please contact an administrator." : "Si non dd'as pedidu tue, cuntata s'amministratzione.",
    "Your email address on %s was changed." : "S'indiritzu de posta tuo in %s est istadu cambiadu.",
    "Your email address on %s was changed by an administrator." : "S'amministratzione at cambiadu s'indiritzu de posta tuo in %s.",
    "Email address for %1$s changed on %2$s" : "S'indiritzu de posta pro %1$s est cambiadu in %2$s",
    "Email address changed for %s" : "Indiritzu de posta cambiadu in %s",
    "The new email address is %s" : "S'indiritzu nou de posta eletrònica est %s",
    "Your %s account was created" : "Su contu tuo %s est istadu creadu",
    "Welcome aboard" : "Ti donamus sa benebènnida",
    "Welcome aboard %s" : "Ti donamus sa benebènnida %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Ti donamus sa benebènnida a su contu %s, podes agiùnghere, amparare e cumpartzire is datos tuos.",
    "Set your password" : "Imposta sa crae tua",
    "Go to %s" : "Bae a %s",
    "Install Client" : "Installa aplicatzione",
    "Apps" : "Aplicatziones",
    "Personal" : "Personale",
    "Administration" : "Amministratzione",
    "Users" : "Utentes",
    "Additional settings" : "Cunfiguratziones in agiunta",
    "Groupware" : "Groupware",
    "Overview" : "Panoràmica",
    "Basic settings" : "Cunfiguratzione de base",
    "Sharing" : "Cumpartzidura",
    "Calendar" : "Calendàriu",
    "Personal info" : "Informatziones personales",
    "Mobile & desktop" : "Mòbile e de iscrivania",
    "Email server" : "Serbidore posta eletrònica",
    "Security & setup warnings" : "Avisos de seguresa e cunfiguratzione",
    "Background jobs" : "Atividades de background",
    "Unlimited" : "Chene lìmites",
    "Verifying" : "Averguende",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In sa base de datos mancat calicuna colunna optzionale. Agiùnghere is colunnas optzionale a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-columns\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is colunnas sunt agiuntas unas cantas funtzionalidades diant pòdere resurtare prus reativos o prus bellu a impreare. ",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In sa base de datos mancat calicuna crae primària. Agiùnghere is craes primàrias a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-primary-keys\". Si podent agiùnghere a manu is craes primàrias chi mancant in s'interis chi s'istàntzia est in funtzione.",
    "Disabled" : "Disativadu",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Su formadu betzu de tzifradura ladu serbidore est ativu. Racumandamus de ddu disativare. ",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Sa funtzione PHP \"set_time_limit\" no est disponìbile. Custu podet essire in programmas firmados in cursu de esecutzione, trunchende s'installatzione. Est cussigiadu meda a ativare custa funtzione.",
    "Supported" : "Suportadu",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de sa cunfiguratzione.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paret chi PHP no est cunfigradu comente si depet pro rechèrrere variàbiles de ambiente de sistema. Sa proa cun getenv(\"PATH\") at torradu isceti una isceda bòida.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Sa cunfinguratzione de letura isceti est istètia ativada. Custu evitat de pònere cunfiguratziones cun sa interfache-web. In prus, s'archìviu depet èssere produidu pro èssere iscritu a manu a cada agiornamentu.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Sa base de datos tua non funtzionat cun su livellu de isulamentu de sa transatzione \"READ COMMITTED\". Custu podet causare problemas cando si faghent prus atziones in parallelu.",
    "Nextcloud settings" : "Cunfiguratzione de Nextcloud",
    "Image generation" : "Generatzione de immàgines",
    "None" : "Perunu",
    "Allow apps to use the Share API" : "Permite a is aplicatzione de impreare is API de cumpartzidura",
    "Allow resharing" : "Permite de torrare a cumpartzire",
    "Allow sharing with groups" : "Permite cumpartzidura cun grupos",
    "Restrict users to only share with users in their groups" : "Lìmita is utentes a sa cumpartzidura isceti cun utentes in is grupos issoro",
    "Allow users to share via link and emails" : "Permite a is utentes de cumpartzire tràmite ligòngios e posta eletrònica",
    "Allow public uploads" : "Permite carrigamentos pùblicos",
    "Always ask for a password" : "Pedi semper una crae",
    "Enforce password protection" : "Impone sa bardiadura de sa crae",
    "Set default expiration date for shares" : "Imposta sa data de iscadèntzia predefinida pro is cumpartziduras",
    "Enforce expiration date" : "Impone data de iscadèntzia",
    "Set default expiration date for shares to other servers" : "Imposta sa data de iscadèntzia predefinida pro is cumpartziduras a àteros serbidores",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si sa cumponidura automàtica \"matessi grupu\" e \"integratzione de nùmeru de telèfonu\" sunt ativadas, una currispondèntzia in unu de is duas bastat a mustrare s'utente.",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mustra sa liberatòria in sa pàgina de carrigamentu de su ligòngiu pùblicu (mustradu isceti cando s'archìviu de sa lista est cuadu)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Custu testu s'at a mustrare in sa pàgina de carrigamentu de su ligòngiu pùblicu cando s'archìviu de sa lista est cuadu.",
    "Default share permissions" : "Permissos de cumpartzidura predefinidos",
    "Two-Factor Authentication" : "Autenticatzione a duos fatores",
    "Enforce two-factor authentication" : "Àplica s'autenticatzione a duos fatores",
    "Limit to groups" : "Lìmita a grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "S'aplicatzione de s'autenticatzione a duos fatores si podet impostare isceti pro tzertos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "S'autenticatzione a duos fatores est impostada pro totu is cumponentes de is grupos in fatu.",
    "Enforced groups" : "Grupos impostos",
    "Two-factor authentication is not enforced for members of the following groups." : "S'autenticatzione a duos fatores no est imposta pro cumponentes de is grupos in fatu.",
    "Excluded groups" : "Grupos esclùdidos",
    "Save changes" : "Sarva càmbios",
    "Update to {update}" : "Agiorna a {update}",
    "Remove" : "Boga",
    "Disable" : "Disativa",
    "Featured" : "In evidèntzia",
    "This app is supported via your current Nextcloud subscription." : "Custa aplicatzione est suportada dae sa sutaiscritzione atuale tua in Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Is aplicatziones in evidèntzia sunt isvilupadas dae e cun sa comunidade. Oferint funtzionalidades noas e sunt prontas pro s'impreu in produtzione.",
    "Icon" : "Icona",
    "Name" : "Nùmene",
    "Version" : "Versione",
    "Level" : "Livellu",
    "Actions" : "Atziones",
    "Results from other categories" : "Resurtados dae àteras categorias",
    "No apps found for your version" : "Peruna aplicatzione agatada pro sa versione tua",
    "Disable all" : "Disativa totu",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicatzione tenet un'agiornamentu a disponimentu","%n aplicatziones tenent un'agiornamentu a disponimentu"],
    "Loading" : "Carrighende",
    "Description" : "Descritzione",
    "Details" : "Detàllios",
    "All" : "Totu",
    "Limit app usage to groups" : "Lìmita s'impreu de s'aplicatzione a grupos",
    "No results" : "Perunu resurtadu",
    "Update to {version}" : "Agiorna a  {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione mìnima de Nextcloud assignada. At a èssere unu problema in su benidore.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione màssima de Nextcloud assignada. At a èssere unu problema in su benidore.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Non faghet a installare custa aplicatzione ca is dipendèntzias in fatu non sunt  satisfatos:",
    "Author" : "Autoria",
    "Categories" : "Categ",
    "Resources" : "Risorsas",
    "Documentation" : "Documentatzione",
    "Report a bug" : "Signala un'errore",
    "Request feature" : "Rechede funtzionalidade",
    "Ask questions or discuss" : "Faghe preguntas o discuti",
    "Rate" : "Vàluta",
    "View in store" : "Càstia in s'archìviu",
    "Visit website" : "Vìsita su situ",
    "Admin documentation" : "Documentatzione amministratzione",
    "Developer documentation" : "Documentatzione isvilupu",
    "Changelog" : "Registru de is càmbios",
    "Marked for remote wipe" : "Marcadu pro cantzelladura remota",
    "Device settings" : "Cunfiguratzione de su dispositivu",
    "Allow filesystem access" : "Permite s'intrada a su sistema de is archìvios",
    "Rename" : "Torra a numenare",
    "Revoke" : "Rèvoca",
    "Wipe device" : "Cantzella dispositivu",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "{productName} iOS app" : "{productName} aplicatzione iOS ",
    "{productName} Android app" : "{productName} aplicatzione Android",
    "{productName} Talk for iOS" : "{productName} Talk pro iOS",
    "{productName} Talk for Android" : "{productName} Talk pro Android",
    "This session" : "Custa sessione",
    "Device" : "Dispositivu",
    "Last activity" : "Ùrtima atividade",
    "Devices & sessions" : "Dispositivos & sessiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de iscrivania e mòbiles collegados immoe in su contu tuo.",
    "App name" : "Nùmene de s'aplicatzione",
    "Create new app password" : "Crea una crae noa de aplicatzione",
    "Error while creating device token" : "Errore creende su token de su dispositivu",
    "Login" : "Atzessu",
    "Password" : "Crae",
    "Show QR code for mobile apps" : "Mustra su còdighe QR pro aplicatziones mòbiles",
    "Could not copy app password. Please copy it manually." : "No at fatu a copiare sa crae. Copia·dda a manu.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Imprea su servìtziu cron de sistema pro cramare s'archìviu cron.php cada 5 minutos.",
    "Profile" : "Profilu",
    "Enable" : "Ativa",
    "Server-side encryption" : "Tzifradura ladu serbidore",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sa tzifradura ladu serbidore permitit de tzifrare is archìvios chi sunt carrigados in custu serbidore. Bi sunt limitatziones comente prestatziones prus bàscias, tando ativa•ddu isceti chi est netzessàriu.",
    "Enable server-side encryption" : "Ativa  tzifradura ladu serbidore",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una borta chi sa tzifradura est ativada, totu is archìvios carrigados in su serbidore dae cussu momentu ant a èssere tzifrados in su serbidore. S'at a pòdere disativare sa tzifradura a pustis, si su mòdulu de tzifradura ativu ddu permitit, e totu is pre-cunditziones (comente sa cunfiguratzione de una crae de recùperu) sunt cumproadas.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Sa tzifradura a sa sola no assegurat sa seguresa de su sistema. Càstia sa documentatzione pro àteras informatziones subra su funtzionamentu de s'aplicatzione pro sa tzifradura, e is genias de impreu suportadas.",
    "Be aware that encryption always increases the file size." : "Regorda ca sa tzifradura creschet semper sa mannària de s'archìviu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Benit semper a bene a creare còpias de seguresa regulares de is datos tuos, in casu de tzifradura assegura•ti de creare còpia de is craes de tzfradura paris cun is datos tuos.",
    "This is the final warning: Do you really want to enable encryption?" : "Custu est s'ùrtimu avisu : a beru boles ativare sa tzifradura?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Perunu mòdulu de tzifradura carrigadu, ativa sa tzifradura in su menu de is aplicatziones.",
    "Select default encryption module:" : "Seletziona mòdulu de tzifradura predefinidu:",
    "Cancel" : "Annulla",
    "Confirm" : "Cunfirma",
    "Submit" : "Imbia",
    "Remove group" : "Boga·nche grupu",
    "Current password" : "Crae currente",
    "New password" : "Crae noa",
    "Change password" : "Càmbia crae",
    "Picture provided by original account" : "Immàgine frunida dae su contu originale",
    "You are a member of the following groups:" : "Faghes parte de custos grupos:",
    "Primary email for password reset and notifications" : "Indiritzu de posta eletrònica printzipale pro torrare a impostare sa crae e retzire notìficas",
    "Email options" : "Optziones de posta eletrònica",
    "Remove primary email" : "Boga•nche s'indiritzu de posta eletrònica printzipale",
    "Delete email" : "Cantzella indiritzu de posta eletrònica",
    "Additional email address {index}" : "Segundu indiritzu de posta eletrònica {index}",
    "No email address set" : "Perunu indiritzu de posta eletrònica impostadu",
    "Help translate" : "Agiuda a tradùere",
    "No language set" : "Peruna limba impostada",
    "Your phone number" : "Nùmero tuo de telèfonu",
    "Add" : "Agiunghe",
    "Create" : "Crea",
    "Change" : "Càmbia",
    "Delete" : "Cantzella",
    "Reshare" : "Torra a cumpartzire",
    "Default language" : "Limba predefinida",
    "Common languages" : "Limbas comunes",
    "Password change is disabled because the master key is disabled" : "Su càmbiu de sa crae est disativadu ca sa crae printzipale est disativada",
    "Display name" : "Ammustra nùmene",
    "Email" : "Posta eletrònica",
    "Quota" : "Cuota",
    "Language" : "Limba",
    "Avatar" : "Avatar",
    "Group admin for" : "In amministratzione pro su grupu",
    "Storage location" : "Positzione de s'archiviatzione",
    "Last login" : "Ùrtimu atzessu",
    "Account actions" : "Atziones de su contu",
    "{size} used" : "{size} impreadu",
    "Delete account" : "Cantzella contu",
    "Resend welcome email" : "Torra a imbiare su messàgiu de benebènnida",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In casu de pèrdida de su dispositivu o de essida dae s'organizatzione, custu podet cantzellare dae remotu is datos de Nextcloud dae totu is dispositivos assotziados cun {userid}. Funtzionat isceti si is dispositivos sunt collegados a internet. ",
    "Remote wipe of devices" : "Cantzelladura remota de is dispositivos",
    "Wipe {userid}'s devices" : "Cantzella is dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Cantzella su contu de {userid}, inclùdidos archìvios personales, datos de aplicatziones, etc.",
    "Account deletion" : "Cantzelladura de su contu",
    "Delete {userid}'s account" : "Cantzella su contu de {userid}",
    "Welcome mail sent!" : "Messàgiu de benebènnida imbiadu!",
    "Done" : "Fatu",
    "Edit" : "Modìfica",
    "Show storage path" : "Mustra su percursu de archiviatzione",
    "Show last login" : "Mustra s'ùrtimu atzessu",
    "Sorting" : "Assentende",
    "Send email" : "Imbia messàgiu de posta eletrònica",
    "Default quota" : "Cuota predefinida",
    "Select default quota" : "Seletziona cuota predefinida",
    "Passwordless authentication requires a secure connection." : "S'autenticatzione chene crae rechedet una connessione segura.",
    "Add WebAuthn device" : "Agiunghe dispositivu WebAuthn",
    "Please authorize your WebAuthn device." : "Autoriza su dispositivu WebAuthn tuo.",
    "Adding your device …" : "Agiunghende su dispositivu tuo ...",
    "Server error while trying to complete WebAuthn device registration" : "Errore de su serbidore chirchende de cumpletare sa registratzione de su dispositivu WebAuthn",
    "Unnamed device" : "Dispositivu chene nùmene",
    "Passwordless Authentication" : "Autenticatzione chene crae",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Imposta su contu tuo pro s'autenticatzione chene crae, sighende s'istandard FIDO2.",
    "No devices configured." : "Perunu dispositivu cunfiguradu.",
    "The following devices are configured for your account:" : "Is dispositivos in fatu sunt cunfigurados pro su contu tuo:",
    "Your browser does not support WebAuthn." : "Su serbidore tuo non suportat WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Comente parte de s'amministratzione podes afinigare su cumportamentu de cumpartzidura. Càstia sa documentatzione pro àteras informatziones.",
    "Admins" : "Amministratzione",
    "Sending…" : "Imbiende...",
    "Email sent" : "Messàgiu de posta imbiadu",
    "Location" : "Positzione",
    "Profile picture" : "Immàgine de profilu",
    "About" : "In contu de",
    "Full name" : "Nùmene cumpletu",
    "Headline" : "Tìtulos",
    "Phone number" : "Nùmeru de telèfonu",
    "Role" : "Faina",
    "Website" : "Situ ìnternet",
    "Locale" : "Localizatzione",
    "Your apps" : "Is aplicatziones tuas",
    "Active apps" : "Aplicatziones ativas",
    "Disabled apps" : "Aplicatziones disativadas",
    "Updates" : "Agiornamentos",
    "App bundles" : "Pachetes de aplicatziones",
    "Featured apps" : "Aplicatziones in evidèntzia",
    "Hide" : "Cua",
    "Download and enable" : "Iscàrriga e ativa",
    "The app will be downloaded from the App Store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Custa aplicatzione no est marcada comente cumpatìbile cun sa versione tua de Nextcloud. Si sighis, as a pòdere installare s'aplicatzione. Càstia ca podet èssere chi non funtzionet comente prevìdidu.",
    "Never" : "Mai",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "S'aplicatzione est istada ativada ma tenet bisòngiu de un'agiornamentu. T'amus a deretare a sa pàgina de agiornamentu tra 5 segundos.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Errore: Custa aplicatzione non si podet ativare ca faghet su serbidore no istàbile",
    "Do you really want to wipe your data from this device?" : "A beru boles cantzellare is datos dae custu dispositivu?",
    "Confirm wipe" : "Cunfirma cantzelladura",
    "Error while wiping the device with the token" : "Errore in sa cantzelladura de su dispositivu cun su token",
    "Error while updating device token name" : "Errore agiornende si nùmene de su token de su dispositivu",
    "Error while updating device token scope" : "Errore agiornende s'àmbitu de su token de su dispositivu",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
    "Error" : "Errore",
    "Forum" : "Forum",
    "Legal notice" : "Avisu legale",
    "Privacy policy" : "Critèriu de riservadesa",
    "Open documentation" : "Aberi documentatzione",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Est importante a impostare custu serbidore pro imbiare messàgios de posta eletrònica, pro re-impostare sa crae e pro is notìficas. ",
    "Send mode" : "Modalidade de imbiu",
    "Encryption" : "Tzifradura",
    "Sendmail mode" : "Modalidade de imbiu de posta",
    "From address" : "Indiritzu de chie imbiat",
    "Server address" : "Indiritzu de su serbidore",
    "Port" : "Porta",
    "Authentication" : "Autenticatzione",
    "Authentication required" : "Autenticatzione recherta",
    "Credentials" : "Credentziales",
    "SMTP Password" : "Crae SMTP",
    "Save" : "Sarva",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Est importante pro sa seguresa e s'esecutzione de s'istàntzia tua chi totu siat cunfiguradu bene. Pro t'agiudare, semus faghende controllos automàticos. Càstia sa documentatzione in ligòngiu pro àteras informatziones.",
    "All checks passed." : "Passados totu is controllos.",
    "There are some errors regarding your setup." : "B'at errores in sa cunfiguratzione tua.",
    "There are some warnings regarding your setup." : "B'at avisos in sa cunfiguratzione tua",
    "Checking for system and security issues." : "Verìfica de is problemas de sistema e seguresa.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Càstia bene is <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">ghias de installatzione ↗</a>, e controlla is errores o is avisos in su <a href=\"%2$s\">registru</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla sa seguresa de Nextcloud in <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">s'iscansione nostra de seguresa ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Resones pro impreare Nextcloud in s'organizatzione tua",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Isvilupadu dae {communityopen}comunidadeNextcloud {linkclose}, su {githubopen}còdighe de orìgine{linkclose} est lissentziadu pro {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Pone•ddi M'agradat a sa pàgina Facebook nostra",
    "Follow us on Twitter" : "Sighi•nosi in Twitter",
    "Follow us on Mastodon" : "Sighi•nos in Mastodon",
    "Check out our blog" : "Leghe·ti su blog nostru",
    "Subscribe to our newsletter" : "Iscrie·ti a sa lista de messàgios nostra",
    "Use a second factor besides your password to increase security for your account." : "Imprea unu segundu fatore a parte sa crae tua pro crèschere sa seguresa de su contu tuo.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si impreas aplicatziones de sa de tres partes pro ti connètere a Nextcloud, assegura•ti de creare e cunfigurare una crae pro cada aplicatzione antis de ativare su segundu fatore de autenticatzione.",
    "No user supplied" : "Peruna utèntzia frunida",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fruni una crae amministrativa de riprìstinu; si nono, s'ant a perdere totu is datos de utente.",
    "Invalid user" : "Utèntzia non bàlida",
    "Your username is: %s" : "Su nùmene utente tuo est: %s",
    "Logged in user must be a subadmin" : "S'utente devet essere de sa suta-amministratzione ",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Un'atividade in segundu pianu est in isetu pro controllare is tzertificados SSL importados dae s'utente. Torra a controllare prus a tardu.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "B'at tzertificados SSL importados dae utentes chi non s'impreant prus cun Nextcloud 21. Si podent importare in sa lìnia de cumandu tràmite su cumandu \"occ security:certificates:import\". Is percursos issoro in sa cartella de is datos sunt mustrados in fatu.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
    "Exclude groups from sharing" : "Esclude grupos dae sa cumpartzidura",
    "These groups will still be able to receive shares, but not to initiate them." : "Custos grupos ant a pòdere retzire cumpartziduras, ma no ddas ant a pòdere cumintzare.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "S'autenticatzione a duos fatores si podet aplicare a totu is utentes e grupos ispetzìficos. Si non tenent unu frunidore a duos fatores cunfiguradu, no ant a pòdere intrare in su sistema.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando si seletzionant/escludent grupos, pro determinare si un'utente at aplicadu 2FA, s'impreat sa lògica in fatu: si non si seletzionat perunu grupu, 2FA est ativu pro chie chi siat, francu pro cumponentes de grupos esclùdidos. Si un'utente est siat in unu grupu seletzionadu siat in unu esclùdidu, cussu seletzionadu passat in antis e 2FA est aplicadu.",
    "{license}-licensed" : "suta lissèntzia {license}",
    "Username" : "Nùmene utente",
    "New user" : "Utèntzia noa",
    "User backend" : "Motore utente",
    "You do not have permissions to see the details of this user" : "Non tenes is permissos pro bìdere is detàllios de s'utente",
    "Add user to group" : "Agiunghe un'utente a unu grupu",
    "Set user as admin for" : "Include a un'utente in s'amministratzione pro",
    "Select user quota" : "Seletziona cuota utente",
    "Delete user" : "Cantzella utente",
    "Wipe all devices" : "Cantzella totu is dispositivos",
    "Disable user" : "Disativa utente",
    "Enable user" : "Ativa utente",
    "Toggle user actions menu" : "Càmbia su menu de is atziones de s'utente",
    "Show user backend" : "Mustra su motore utente",
    "Name your device" : "Nùmena su dispositivu",
    "Server error while trying to add WebAuthn device" : "Errore de su serbidore chirchende de agiùnghere su dispositivu WebAuthn",
    "by {author}\n{license}" : "de {author}\n{license}",
    "Active users" : "Utèntzias ativas",
    "Disabled users" : "Disativa utentes",
    "SMTP Username" : "Nùmene utente SMTP "
},
"nplurals=2; plural=(n != 1);");
